pub struct ImpersonateFiller {
from: Address,
}Expand description
A filler that sets the from field on transactions to impersonate a specific address.
This is useful when using Anvil’s impersonation features to send transactions from
accounts that we don’t have the private key for.
Avoids having to manually set the from field on transactions.
Fields
from: AddressImplementations